# -*- coding: utf-8 -*-
# flake8: noqa
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: draft/protos/ydb_keyvalue.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ydb._grpc.v3.protos import ydb_operation_pb2 as protos_dot_ydb__operation__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='draft/protos/ydb_keyvalue.proto',
  package='Ydb.KeyValue',
  syntax='proto3',
  serialized_options=b'\n tech.ydb.proto.draft.keyvalue.v1ZAgithub.com/ydb-platform/ydb-go-genproto/draft/protos/Ydb_KeyValue\370\001\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1f\x64raft/protos/ydb_keyvalue.proto\x12\x0cYdb.KeyValue\x1a\x1aprotos/ydb_operation.proto\"\xf0\x01\n\x12StorageChannelInfo\x12\x17\n\x0fstorage_channel\x18\x01 \x01(\r\x12@\n\x0bstatus_flag\x18\x02 \x01(\x0e\x32+.Ydb.KeyValue.StorageChannelInfo.StatusFlag\"\x7f\n\nStatusFlag\x12\x1b\n\x17STATUS_FLAG_UNSPECIFIED\x10\x00\x12\x15\n\x11STATUS_FLAG_GREEN\x10\n\x12\x1b\n\x17STATUS_FLAG_YELLOW_STOP\x10\x14\x12 \n\x1cSTATUS_FLAG_ORANGE_OUT_SPACE\x10\x1e\"b\n\nPriorities\"T\n\x08Priority\x12\x18\n\x14PRIORITY_UNSPECIFIED\x10\x00\x12\x15\n\x11PRIORITY_REALTIME\x10\x01\x12\x17\n\x13PRIORITY_BACKGROUND\x10\x02\"k\n\rStorageConfig\x12:\n\x07\x63hannel\x18\x01 \x03(\x0b\x32).Ydb.KeyValue.StorageConfig.ChannelConfig\x1a\x1e\n\rChannelConfig\x12\r\n\x05media\x18\x01 \x01(\t\"\x98\x01\n\x08KeyRange\x12\x1c\n\x12\x66rom_key_inclusive\x18\x01 \x01(\tH\x00\x12\x1c\n\x12\x66rom_key_exclusive\x18\x02 \x01(\tH\x00\x12\x1a\n\x10to_key_inclusive\x18\x03 \x01(\tH\x01\x12\x1a\n\x10to_key_exclusive\x18\x04 \x01(\tH\x01\x42\x0c\n\nfrom_boundB\n\n\x08to_bound\"s\n\x12\x41\x63quireLockRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x0c\n\x04path\x18\x02 \x01(\t\x12\x14\n\x0cpartition_id\x18\x03 \x01(\x04\"C\n\x13\x41\x63quireLockResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"=\n\x11\x41\x63quireLockResult\x12\x17\n\x0flock_generation\x18\x01 \x01(\x04\x12\x0f\n\x07node_id\x18\x02 \x01(\r\"\xac\t\n\x19\x45xecuteTransactionRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x0c\n\x04path\x18\x02 \x01(\t\x12\x14\n\x0cpartition_id\x18\x03 \x01(\x04\x12\x1c\n\x0flock_generation\x18\x04 \x01(\x04H\x00\x88\x01\x01\x12\x41\n\x08\x63ommands\x18\x05 \x03(\x0b\x32/.Ydb.KeyValue.ExecuteTransactionRequest.Command\x1a\xba\x07\n\x07\x43ommand\x12S\n\x0c\x64\x65lete_range\x18\x01 \x01(\x0b\x32;.Ydb.KeyValue.ExecuteTransactionRequest.Command.DeleteRangeH\x00\x12H\n\x06rename\x18\x02 \x01(\x0b\x32\x36.Ydb.KeyValue.ExecuteTransactionRequest.Command.RenameH\x00\x12O\n\ncopy_range\x18\x03 \x01(\x0b\x32\x39.Ydb.KeyValue.ExecuteTransactionRequest.Command.CopyRangeH\x00\x12H\n\x06\x63oncat\x18\x04 \x01(\x0b\x32\x36.Ydb.KeyValue.ExecuteTransactionRequest.Command.ConcatH\x00\x12\x46\n\x05write\x18\x05 \x01(\x0b\x32\x35.Ydb.KeyValue.ExecuteTransactionRequest.Command.WriteH\x00\x1a*\n\x06Rename\x12\x0f\n\x07old_key\x18\x01 \x01(\t\x12\x0f\n\x07new_key\x18\x02 \x01(\t\x1a\x45\n\x06\x43oncat\x12\x12\n\ninput_keys\x18\x01 \x03(\t\x12\x12\n\noutput_key\x18\x02 \x01(\t\x12\x13\n\x0bkeep_inputs\x18\x03 \x01(\x08\x1a\x63\n\tCopyRange\x12%\n\x05range\x18\x01 \x01(\x0b\x32\x16.Ydb.KeyValue.KeyRange\x12\x18\n\x10prefix_to_remove\x18\x02 \x01(\t\x12\x15\n\rprefix_to_add\x18\x03 \x01(\t\x1a\x94\x02\n\x05Write\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c\x12\x17\n\x0fstorage_channel\x18\x03 \x01(\r\x12\x33\n\x08priority\x18\x04 \x01(\x0e\x32!.Ydb.KeyValue.Priorities.Priority\x12L\n\x06tactic\x18\x05 \x01(\x0e\x32<.Ydb.KeyValue.ExecuteTransactionRequest.Command.Write.Tactic\"S\n\x06Tactic\x12\x16\n\x12TACTIC_UNSPECIFIED\x10\x00\x12\x19\n\x15TACTIC_MAX_THROUGHPUT\x10\x01\x12\x16\n\x12TACTIC_MIN_LATENCY\x10\x02\x1a\x34\n\x0b\x44\x65leteRange\x12%\n\x05range\x18\x01 \x01(\x0b\x32\x16.Ydb.KeyValue.KeyRangeB\x08\n\x06\x61\x63tionB\x12\n\x10_lock_generation\"J\n\x1a\x45xecuteTransactionResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"k\n\x18\x45xecuteTransactionResult\x12>\n\x14storage_channel_info\x18\x01 \x03(\x0b\x32 .Ydb.KeyValue.StorageChannelInfo\x12\x0f\n\x07node_id\x18\x02 \x01(\r\"\x93\x02\n\x0bReadRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x0c\n\x04path\x18\x02 \x01(\t\x12\x14\n\x0cpartition_id\x18\x03 \x01(\x04\x12\x1c\n\x0flock_generation\x18\x04 \x01(\x04H\x00\x88\x01\x01\x12\x0b\n\x03key\x18\x05 \x01(\t\x12\x0e\n\x06offset\x18\x06 \x01(\x04\x12\x0c\n\x04size\x18\x07 \x01(\x04\x12\x13\n\x0blimit_bytes\x18\x08 \x01(\x04\x12\x33\n\x08priority\x18\t \x01(\x0e\x32!.Ydb.KeyValue.Priorities.PriorityB\x12\n\x10_lock_generation\"<\n\x0cReadResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"\x89\x01\n\nReadResult\x12\x15\n\rrequested_key\x18\x01 \x01(\t\x12\x18\n\x10requested_offset\x18\x02 \x01(\x04\x12\x16\n\x0erequested_size\x18\x03 \x01(\x04\x12\r\n\x05value\x18\x04 \x01(\x0c\x12\x12\n\nis_overrun\x18\x05 \x01(\x08\x12\x0f\n\x07node_id\x18\x06 \x01(\r\"\x94\x02\n\x10ReadRangeRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x0c\n\x04path\x18\x02 \x01(\t\x12\x14\n\x0cpartition_id\x18\x03 \x01(\x04\x12\x1c\n\x0flock_generation\x18\x04 \x01(\x04H\x00\x88\x01\x01\x12%\n\x05range\x18\x05 \x01(\x0b\x32\x16.Ydb.KeyValue.KeyRange\x12\x13\n\x0blimit_bytes\x18\x06 \x01(\x04\x12\x33\n\x08priority\x18\x07 \x01(\x0e\x32!.Ydb.KeyValue.Priorities.PriorityB\x12\n\x10_lock_generation\"A\n\x11ReadRangeResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"\xd1\x01\n\x0fReadRangeResult\x12\x38\n\x04pair\x18\x01 \x03(\x0b\x32*.Ydb.KeyValue.ReadRangeResult.KeyValuePair\x12\x12\n\nis_overrun\x18\x02 \x01(\x08\x12\x0f\n\x07node_id\x18\x03 \x01(\r\x1a_\n\x0cKeyValuePair\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c\x12\x1a\n\x12\x63reation_unix_time\x18\x04 \x01(\x04\x12\x17\n\x0fstorage_channel\x18\x05 \x01(\r\"\xdf\x01\n\x10ListRangeRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x0c\n\x04path\x18\x02 \x01(\t\x12\x14\n\x0cpartition_id\x18\x03 \x01(\x04\x12\x1c\n\x0flock_generation\x18\x04 \x01(\x04H\x00\x88\x01\x01\x12%\n\x05range\x18\x05 \x01(\x0b\x32\x16.Ydb.KeyValue.KeyRange\x12\x13\n\x0blimit_bytes\x18\x06 \x01(\x04\x42\x12\n\x10_lock_generation\"A\n\x11ListRangeResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"\xcb\x01\n\x0fListRangeResult\x12\x32\n\x03key\x18\x01 \x03(\x0b\x32%.Ydb.KeyValue.ListRangeResult.KeyInfo\x12\x12\n\nis_overrun\x18\x02 \x01(\x08\x12\x0f\n\x07node_id\x18\x03 \x01(\r\x1a_\n\x07KeyInfo\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x12\n\nvalue_size\x18\x02 \x01(\r\x12\x1a\n\x12\x63reation_unix_time\x18\x03 \x01(\x04\x12\x17\n\x0fstorage_channel\x18\x04 \x01(\r\"\xca\x01\n\x1eGetStorageChannelStatusRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x0c\n\x04path\x18\x02 \x01(\t\x12\x14\n\x0cpartition_id\x18\x03 \x01(\x04\x12\x1c\n\x0flock_generation\x18\x04 \x01(\x04H\x00\x88\x01\x01\x12\x17\n\x0fstorage_channel\x18\x05 \x03(\rB\x12\n\x10_lock_generation\"O\n\x1fGetStorageChannelStatusResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"p\n\x1dGetStorageChannelStatusResult\x12>\n\x14storage_channel_info\x18\x01 \x03(\x0b\x32 .Ydb.KeyValue.StorageChannelInfo\x12\x0f\n\x07node_id\x18\x02 \x01(\r\"\xac\x01\n\x13\x43reateVolumeRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x0c\n\x04path\x18\x02 \x01(\t\x12\x17\n\x0fpartition_count\x18\x04 \x01(\r\x12\x33\n\x0estorage_config\x18\x05 \x01(\x0b\x32\x1b.Ydb.KeyValue.StorageConfig\"D\n\x14\x43reateVolumeResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"\x14\n\x12\x43reateVolumeResult\"\\\n\x11\x44ropVolumeRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x0c\n\x04path\x18\x02 \x01(\t\"B\n\x12\x44ropVolumeResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"\x12\n\x10\x44ropVolumeResult\"\xb1\x01\n\x12\x41lterVolumeRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x0c\n\x04path\x18\x02 \x01(\t\x12\x1d\n\x15\x61lter_partition_count\x18\x03 \x01(\r\x12\x33\n\x0estorage_config\x18\x04 \x01(\x0b\x32\x1b.Ydb.KeyValue.StorageConfig\"C\n\x13\x41lterVolumeResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"\x13\n\x11\x41lterVolumeResult\"`\n\x15\x44\x65scribeVolumeRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x0c\n\x04path\x18\x02 \x01(\t\"F\n\x16\x44\x65scribeVolumeResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"=\n\x14\x44\x65scribeVolumeResult\x12\x0c\n\x04path\x18\x01 \x01(\t\x12\x17\n\x0fpartition_count\x18\x02 \x01(\x04\"v\n\x1aListLocalPartitionsRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x0c\n\x04path\x18\x02 \x01(\t\x12\x0f\n\x07node_id\x18\x03 \x01(\x04\"K\n\x1bListLocalPartitionsResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"Q\n\x19ListLocalPartitionsResult\x12\x0c\n\x04path\x18\x01 \x01(\t\x12\x0f\n\x07node_id\x18\x02 \x01(\x04\x12\x15\n\rpartition_ids\x18\x03 \x03(\x04\x42h\n tech.ydb.proto.draft.keyvalue.v1ZAgithub.com/ydb-platform/ydb-go-genproto/draft/protos/Ydb_KeyValue\xf8\x01\x01\x62\x06proto3'
  ,
  dependencies=[protos_dot_ydb__operation__pb2.DESCRIPTOR,])



_STORAGECHANNELINFO_STATUSFLAG = _descriptor.EnumDescriptor(
  name='StatusFlag',
  full_name='Ydb.KeyValue.StorageChannelInfo.StatusFlag',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='STATUS_FLAG_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STATUS_FLAG_GREEN', index=1, number=10,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STATUS_FLAG_YELLOW_STOP', index=2, number=20,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STATUS_FLAG_ORANGE_OUT_SPACE', index=3, number=30,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=191,
  serialized_end=318,
)
_sym_db.RegisterEnumDescriptor(_STORAGECHANNELINFO_STATUSFLAG)

_PRIORITIES_PRIORITY = _descriptor.EnumDescriptor(
  name='Priority',
  full_name='Ydb.KeyValue.Priorities.Priority',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='PRIORITY_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PRIORITY_REALTIME', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PRIORITY_BACKGROUND', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=334,
  serialized_end=418,
)
_sym_db.RegisterEnumDescriptor(_PRIORITIES_PRIORITY)

_EXECUTETRANSACTIONREQUEST_COMMAND_WRITE_TACTIC = _descriptor.EnumDescriptor(
  name='Tactic',
  full_name='Ydb.KeyValue.ExecuteTransactionRequest.Command.Write.Tactic',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='TACTIC_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TACTIC_MAX_THROUGHPUT', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TACTIC_MIN_LATENCY', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1963,
  serialized_end=2046,
)
_sym_db.RegisterEnumDescriptor(_EXECUTETRANSACTIONREQUEST_COMMAND_WRITE_TACTIC)


_STORAGECHANNELINFO = _descriptor.Descriptor(
  name='StorageChannelInfo',
  full_name='Ydb.KeyValue.StorageChannelInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='storage_channel', full_name='Ydb.KeyValue.StorageChannelInfo.storage_channel', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status_flag', full_name='Ydb.KeyValue.StorageChannelInfo.status_flag', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _STORAGECHANNELINFO_STATUSFLAG,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=78,
  serialized_end=318,
)


_PRIORITIES = _descriptor.Descriptor(
  name='Priorities',
  full_name='Ydb.KeyValue.Priorities',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PRIORITIES_PRIORITY,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=320,
  serialized_end=418,
)


_STORAGECONFIG_CHANNELCONFIG = _descriptor.Descriptor(
  name='ChannelConfig',
  full_name='Ydb.KeyValue.StorageConfig.ChannelConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='media', full_name='Ydb.KeyValue.StorageConfig.ChannelConfig.media', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=497,
  serialized_end=527,
)

_STORAGECONFIG = _descriptor.Descriptor(
  name='StorageConfig',
  full_name='Ydb.KeyValue.StorageConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='channel', full_name='Ydb.KeyValue.StorageConfig.channel', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_STORAGECONFIG_CHANNELCONFIG, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=420,
  serialized_end=527,
)


_KEYRANGE = _descriptor.Descriptor(
  name='KeyRange',
  full_name='Ydb.KeyValue.KeyRange',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='from_key_inclusive', full_name='Ydb.KeyValue.KeyRange.from_key_inclusive', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='from_key_exclusive', full_name='Ydb.KeyValue.KeyRange.from_key_exclusive', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='to_key_inclusive', full_name='Ydb.KeyValue.KeyRange.to_key_inclusive', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='to_key_exclusive', full_name='Ydb.KeyValue.KeyRange.to_key_exclusive', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='from_bound', full_name='Ydb.KeyValue.KeyRange.from_bound',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='to_bound', full_name='Ydb.KeyValue.KeyRange.to_bound',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=530,
  serialized_end=682,
)


_ACQUIRELOCKREQUEST = _descriptor.Descriptor(
  name='AcquireLockRequest',
  full_name='Ydb.KeyValue.AcquireLockRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation_params', full_name='Ydb.KeyValue.AcquireLockRequest.operation_params', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='path', full_name='Ydb.KeyValue.AcquireLockRequest.path', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='partition_id', full_name='Ydb.KeyValue.AcquireLockRequest.partition_id', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=684,
  serialized_end=799,
)


_ACQUIRELOCKRESPONSE = _descriptor.Descriptor(
  name='AcquireLockResponse',
  full_name='Ydb.KeyValue.AcquireLockResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation', full_name='Ydb.KeyValue.AcquireLockResponse.operation', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=801,
  serialized_end=868,
)


_ACQUIRELOCKRESULT = _descriptor.Descriptor(
  name='AcquireLockResult',
  full_name='Ydb.KeyValue.AcquireLockResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='lock_generation', full_name='Ydb.KeyValue.AcquireLockResult.lock_generation', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='node_id', full_name='Ydb.KeyValue.AcquireLockResult.node_id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=870,
  serialized_end=931,
)


_EXECUTETRANSACTIONREQUEST_COMMAND_RENAME = _descriptor.Descriptor(
  name='Rename',
  full_name='Ydb.KeyValue.ExecuteTransactionRequest.Command.Rename',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='old_key', full_name='Ydb.KeyValue.ExecuteTransactionRequest.Command.Rename.old_key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='new_key', full_name='Ydb.KeyValue.ExecuteTransactionRequest.Command.Rename.new_key', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1553,
  serialized_end=1595,
)

_EXECUTETRANSACTIONREQUEST_COMMAND_CONCAT = _descriptor.Descriptor(
  name='Concat',
  full_name='Ydb.KeyValue.ExecuteTransactionRequest.Command.Concat',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='input_keys', full_name='Ydb.KeyValue.ExecuteTransactionRequest.Command.Concat.input_keys', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='output_key', full_name='Ydb.KeyValue.ExecuteTransactionRequest.Command.Concat.output_key', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='keep_inputs', full_name='Ydb.KeyValue.ExecuteTransactionRequest.Command.Concat.keep_inputs', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1597,
  serialized_end=1666,
)

_EXECUTETRANSACTIONREQUEST_COMMAND_COPYRANGE = _descriptor.Descriptor(
  name='CopyRange',
  full_name='Ydb.KeyValue.ExecuteTransactionRequest.Command.CopyRange',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='range', full_name='Ydb.KeyValue.ExecuteTransactionRequest.Command.CopyRange.range', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='prefix_to_remove', full_name='Ydb.KeyValue.ExecuteTransactionRequest.Command.CopyRange.prefix_to_remove', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='prefix_to_add', full_name='Ydb.KeyValue.ExecuteTransactionRequest.Command.CopyRange.prefix_to_add', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1668,
  serialized_end=1767,
)

_EXECUTETRANSACTIONREQUEST_COMMAND_WRITE = _descriptor.Descriptor(
  name='Write',
  full_name='Ydb.KeyValue.ExecuteTransactionRequest.Command.Write',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='Ydb.KeyValue.ExecuteTransactionRequest.Command.Write.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='Ydb.KeyValue.ExecuteTransactionRequest.Command.Write.value', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='storage_channel', full_name='Ydb.KeyValue.ExecuteTransactionRequest.Command.Write.storage_channel', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='priority', full_name='Ydb.KeyValue.ExecuteTransactionRequest.Command.Write.priority', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tactic', full_name='Ydb.KeyValue.ExecuteTransactionRequest.Command.Write.tactic', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _EXECUTETRANSACTIONREQUEST_COMMAND_WRITE_TACTIC,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1770,
  serialized_end=2046,
)

_EXECUTETRANSACTIONREQUEST_COMMAND_DELETERANGE = _descriptor.Descriptor(
  name='DeleteRange',
  full_name='Ydb.KeyValue.ExecuteTransactionRequest.Command.DeleteRange',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='range', full_name='Ydb.KeyValue.ExecuteTransactionRequest.Command.DeleteRange.range', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2048,
  serialized_end=2100,
)

_EXECUTETRANSACTIONREQUEST_COMMAND = _descriptor.Descriptor(
  name='Command',
  full_name='Ydb.KeyValue.ExecuteTransactionRequest.Command',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='delete_range', full_name='Ydb.KeyValue.ExecuteTransactionRequest.Command.delete_range', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rename', full_name='Ydb.KeyValue.ExecuteTransactionRequest.Command.rename', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='copy_range', full_name='Ydb.KeyValue.ExecuteTransactionRequest.Command.copy_range', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='concat', full_name='Ydb.KeyValue.ExecuteTransactionRequest.Command.concat', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='write', full_name='Ydb.KeyValue.ExecuteTransactionRequest.Command.write', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_EXECUTETRANSACTIONREQUEST_COMMAND_RENAME, _EXECUTETRANSACTIONREQUEST_COMMAND_CONCAT, _EXECUTETRANSACTIONREQUEST_COMMAND_COPYRANGE, _EXECUTETRANSACTIONREQUEST_COMMAND_WRITE, _EXECUTETRANSACTIONREQUEST_COMMAND_DELETERANGE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='action', full_name='Ydb.KeyValue.ExecuteTransactionRequest.Command.action',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=1156,
  serialized_end=2110,
)

_EXECUTETRANSACTIONREQUEST = _descriptor.Descriptor(
  name='ExecuteTransactionRequest',
  full_name='Ydb.KeyValue.ExecuteTransactionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation_params', full_name='Ydb.KeyValue.ExecuteTransactionRequest.operation_params', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='path', full_name='Ydb.KeyValue.ExecuteTransactionRequest.path', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='partition_id', full_name='Ydb.KeyValue.ExecuteTransactionRequest.partition_id', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lock_generation', full_name='Ydb.KeyValue.ExecuteTransactionRequest.lock_generation', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='commands', full_name='Ydb.KeyValue.ExecuteTransactionRequest.commands', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_EXECUTETRANSACTIONREQUEST_COMMAND, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_lock_generation', full_name='Ydb.KeyValue.ExecuteTransactionRequest._lock_generation',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=934,
  serialized_end=2130,
)


_EXECUTETRANSACTIONRESPONSE = _descriptor.Descriptor(
  name='ExecuteTransactionResponse',
  full_name='Ydb.KeyValue.ExecuteTransactionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation', full_name='Ydb.KeyValue.ExecuteTransactionResponse.operation', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2132,
  serialized_end=2206,
)


_EXECUTETRANSACTIONRESULT = _descriptor.Descriptor(
  name='ExecuteTransactionResult',
  full_name='Ydb.KeyValue.ExecuteTransactionResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='storage_channel_info', full_name='Ydb.KeyValue.ExecuteTransactionResult.storage_channel_info', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='node_id', full_name='Ydb.KeyValue.ExecuteTransactionResult.node_id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2208,
  serialized_end=2315,
)


_READREQUEST = _descriptor.Descriptor(
  name='ReadRequest',
  full_name='Ydb.KeyValue.ReadRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation_params', full_name='Ydb.KeyValue.ReadRequest.operation_params', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='path', full_name='Ydb.KeyValue.ReadRequest.path', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='partition_id', full_name='Ydb.KeyValue.ReadRequest.partition_id', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lock_generation', full_name='Ydb.KeyValue.ReadRequest.lock_generation', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='key', full_name='Ydb.KeyValue.ReadRequest.key', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='offset', full_name='Ydb.KeyValue.ReadRequest.offset', index=5,
      number=6, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='size', full_name='Ydb.KeyValue.ReadRequest.size', index=6,
      number=7, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='limit_bytes', full_name='Ydb.KeyValue.ReadRequest.limit_bytes', index=7,
      number=8, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='priority', full_name='Ydb.KeyValue.ReadRequest.priority', index=8,
      number=9, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_lock_generation', full_name='Ydb.KeyValue.ReadRequest._lock_generation',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=2318,
  serialized_end=2593,
)


_READRESPONSE = _descriptor.Descriptor(
  name='ReadResponse',
  full_name='Ydb.KeyValue.ReadResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation', full_name='Ydb.KeyValue.ReadResponse.operation', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2595,
  serialized_end=2655,
)


_READRESULT = _descriptor.Descriptor(
  name='ReadResult',
  full_name='Ydb.KeyValue.ReadResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='requested_key', full_name='Ydb.KeyValue.ReadResult.requested_key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='requested_offset', full_name='Ydb.KeyValue.ReadResult.requested_offset', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='requested_size', full_name='Ydb.KeyValue.ReadResult.requested_size', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='Ydb.KeyValue.ReadResult.value', index=3,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_overrun', full_name='Ydb.KeyValue.ReadResult.is_overrun', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='node_id', full_name='Ydb.KeyValue.ReadResult.node_id', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2658,
  serialized_end=2795,
)


_READRANGEREQUEST = _descriptor.Descriptor(
  name='ReadRangeRequest',
  full_name='Ydb.KeyValue.ReadRangeRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation_params', full_name='Ydb.KeyValue.ReadRangeRequest.operation_params', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='path', full_name='Ydb.KeyValue.ReadRangeRequest.path', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='partition_id', full_name='Ydb.KeyValue.ReadRangeRequest.partition_id', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lock_generation', full_name='Ydb.KeyValue.ReadRangeRequest.lock_generation', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='range', full_name='Ydb.KeyValue.ReadRangeRequest.range', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='limit_bytes', full_name='Ydb.KeyValue.ReadRangeRequest.limit_bytes', index=5,
      number=6, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='priority', full_name='Ydb.KeyValue.ReadRangeRequest.priority', index=6,
      number=7, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_lock_generation', full_name='Ydb.KeyValue.ReadRangeRequest._lock_generation',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=2798,
  serialized_end=3074,
)


_READRANGERESPONSE = _descriptor.Descriptor(
  name='ReadRangeResponse',
  full_name='Ydb.KeyValue.ReadRangeResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation', full_name='Ydb.KeyValue.ReadRangeResponse.operation', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3076,
  serialized_end=3141,
)


_READRANGERESULT_KEYVALUEPAIR = _descriptor.Descriptor(
  name='KeyValuePair',
  full_name='Ydb.KeyValue.ReadRangeResult.KeyValuePair',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='Ydb.KeyValue.ReadRangeResult.KeyValuePair.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='Ydb.KeyValue.ReadRangeResult.KeyValuePair.value', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='creation_unix_time', full_name='Ydb.KeyValue.ReadRangeResult.KeyValuePair.creation_unix_time', index=2,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='storage_channel', full_name='Ydb.KeyValue.ReadRangeResult.KeyValuePair.storage_channel', index=3,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3258,
  serialized_end=3353,
)

_READRANGERESULT = _descriptor.Descriptor(
  name='ReadRangeResult',
  full_name='Ydb.KeyValue.ReadRangeResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='pair', full_name='Ydb.KeyValue.ReadRangeResult.pair', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_overrun', full_name='Ydb.KeyValue.ReadRangeResult.is_overrun', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='node_id', full_name='Ydb.KeyValue.ReadRangeResult.node_id', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_READRANGERESULT_KEYVALUEPAIR, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3144,
  serialized_end=3353,
)


_LISTRANGEREQUEST = _descriptor.Descriptor(
  name='ListRangeRequest',
  full_name='Ydb.KeyValue.ListRangeRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation_params', full_name='Ydb.KeyValue.ListRangeRequest.operation_params', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='path', full_name='Ydb.KeyValue.ListRangeRequest.path', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='partition_id', full_name='Ydb.KeyValue.ListRangeRequest.partition_id', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lock_generation', full_name='Ydb.KeyValue.ListRangeRequest.lock_generation', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='range', full_name='Ydb.KeyValue.ListRangeRequest.range', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='limit_bytes', full_name='Ydb.KeyValue.ListRangeRequest.limit_bytes', index=5,
      number=6, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_lock_generation', full_name='Ydb.KeyValue.ListRangeRequest._lock_generation',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=3356,
  serialized_end=3579,
)


_LISTRANGERESPONSE = _descriptor.Descriptor(
  name='ListRangeResponse',
  full_name='Ydb.KeyValue.ListRangeResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation', full_name='Ydb.KeyValue.ListRangeResponse.operation', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3581,
  serialized_end=3646,
)


_LISTRANGERESULT_KEYINFO = _descriptor.Descriptor(
  name='KeyInfo',
  full_name='Ydb.KeyValue.ListRangeResult.KeyInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='Ydb.KeyValue.ListRangeResult.KeyInfo.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value_size', full_name='Ydb.KeyValue.ListRangeResult.KeyInfo.value_size', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='creation_unix_time', full_name='Ydb.KeyValue.ListRangeResult.KeyInfo.creation_unix_time', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='storage_channel', full_name='Ydb.KeyValue.ListRangeResult.KeyInfo.storage_channel', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3757,
  serialized_end=3852,
)

_LISTRANGERESULT = _descriptor.Descriptor(
  name='ListRangeResult',
  full_name='Ydb.KeyValue.ListRangeResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='Ydb.KeyValue.ListRangeResult.key', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_overrun', full_name='Ydb.KeyValue.ListRangeResult.is_overrun', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='node_id', full_name='Ydb.KeyValue.ListRangeResult.node_id', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_LISTRANGERESULT_KEYINFO, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3649,
  serialized_end=3852,
)


_GETSTORAGECHANNELSTATUSREQUEST = _descriptor.Descriptor(
  name='GetStorageChannelStatusRequest',
  full_name='Ydb.KeyValue.GetStorageChannelStatusRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation_params', full_name='Ydb.KeyValue.GetStorageChannelStatusRequest.operation_params', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='path', full_name='Ydb.KeyValue.GetStorageChannelStatusRequest.path', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='partition_id', full_name='Ydb.KeyValue.GetStorageChannelStatusRequest.partition_id', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lock_generation', full_name='Ydb.KeyValue.GetStorageChannelStatusRequest.lock_generation', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='storage_channel', full_name='Ydb.KeyValue.GetStorageChannelStatusRequest.storage_channel', index=4,
      number=5, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_lock_generation', full_name='Ydb.KeyValue.GetStorageChannelStatusRequest._lock_generation',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=3855,
  serialized_end=4057,
)


_GETSTORAGECHANNELSTATUSRESPONSE = _descriptor.Descriptor(
  name='GetStorageChannelStatusResponse',
  full_name='Ydb.KeyValue.GetStorageChannelStatusResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation', full_name='Ydb.KeyValue.GetStorageChannelStatusResponse.operation', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4059,
  serialized_end=4138,
)


_GETSTORAGECHANNELSTATUSRESULT = _descriptor.Descriptor(
  name='GetStorageChannelStatusResult',
  full_name='Ydb.KeyValue.GetStorageChannelStatusResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='storage_channel_info', full_name='Ydb.KeyValue.GetStorageChannelStatusResult.storage_channel_info', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='node_id', full_name='Ydb.KeyValue.GetStorageChannelStatusResult.node_id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4140,
  serialized_end=4252,
)


_CREATEVOLUMEREQUEST = _descriptor.Descriptor(
  name='CreateVolumeRequest',
  full_name='Ydb.KeyValue.CreateVolumeRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation_params', full_name='Ydb.KeyValue.CreateVolumeRequest.operation_params', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='path', full_name='Ydb.KeyValue.CreateVolumeRequest.path', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='partition_count', full_name='Ydb.KeyValue.CreateVolumeRequest.partition_count', index=2,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='storage_config', full_name='Ydb.KeyValue.CreateVolumeRequest.storage_config', index=3,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4255,
  serialized_end=4427,
)


_CREATEVOLUMERESPONSE = _descriptor.Descriptor(
  name='CreateVolumeResponse',
  full_name='Ydb.KeyValue.CreateVolumeResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation', full_name='Ydb.KeyValue.CreateVolumeResponse.operation', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4429,
  serialized_end=4497,
)


_CREATEVOLUMERESULT = _descriptor.Descriptor(
  name='CreateVolumeResult',
  full_name='Ydb.KeyValue.CreateVolumeResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4499,
  serialized_end=4519,
)


_DROPVOLUMEREQUEST = _descriptor.Descriptor(
  name='DropVolumeRequest',
  full_name='Ydb.KeyValue.DropVolumeRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation_params', full_name='Ydb.KeyValue.DropVolumeRequest.operation_params', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='path', full_name='Ydb.KeyValue.DropVolumeRequest.path', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4521,
  serialized_end=4613,
)


_DROPVOLUMERESPONSE = _descriptor.Descriptor(
  name='DropVolumeResponse',
  full_name='Ydb.KeyValue.DropVolumeResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation', full_name='Ydb.KeyValue.DropVolumeResponse.operation', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4615,
  serialized_end=4681,
)


_DROPVOLUMERESULT = _descriptor.Descriptor(
  name='DropVolumeResult',
  full_name='Ydb.KeyValue.DropVolumeResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4683,
  serialized_end=4701,
)


_ALTERVOLUMEREQUEST = _descriptor.Descriptor(
  name='AlterVolumeRequest',
  full_name='Ydb.KeyValue.AlterVolumeRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation_params', full_name='Ydb.KeyValue.AlterVolumeRequest.operation_params', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='path', full_name='Ydb.KeyValue.AlterVolumeRequest.path', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='alter_partition_count', full_name='Ydb.KeyValue.AlterVolumeRequest.alter_partition_count', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='storage_config', full_name='Ydb.KeyValue.AlterVolumeRequest.storage_config', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4704,
  serialized_end=4881,
)


_ALTERVOLUMERESPONSE = _descriptor.Descriptor(
  name='AlterVolumeResponse',
  full_name='Ydb.KeyValue.AlterVolumeResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation', full_name='Ydb.KeyValue.AlterVolumeResponse.operation', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4883,
  serialized_end=4950,
)


_ALTERVOLUMERESULT = _descriptor.Descriptor(
  name='AlterVolumeResult',
  full_name='Ydb.KeyValue.AlterVolumeResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4952,
  serialized_end=4971,
)


_DESCRIBEVOLUMEREQUEST = _descriptor.Descriptor(
  name='DescribeVolumeRequest',
  full_name='Ydb.KeyValue.DescribeVolumeRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation_params', full_name='Ydb.KeyValue.DescribeVolumeRequest.operation_params', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='path', full_name='Ydb.KeyValue.DescribeVolumeRequest.path', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4973,
  serialized_end=5069,
)


_DESCRIBEVOLUMERESPONSE = _descriptor.Descriptor(
  name='DescribeVolumeResponse',
  full_name='Ydb.KeyValue.DescribeVolumeResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation', full_name='Ydb.KeyValue.DescribeVolumeResponse.operation', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5071,
  serialized_end=5141,
)


_DESCRIBEVOLUMERESULT = _descriptor.Descriptor(
  name='DescribeVolumeResult',
  full_name='Ydb.KeyValue.DescribeVolumeResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='path', full_name='Ydb.KeyValue.DescribeVolumeResult.path', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='partition_count', full_name='Ydb.KeyValue.DescribeVolumeResult.partition_count', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5143,
  serialized_end=5204,
)


_LISTLOCALPARTITIONSREQUEST = _descriptor.Descriptor(
  name='ListLocalPartitionsRequest',
  full_name='Ydb.KeyValue.ListLocalPartitionsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation_params', full_name='Ydb.KeyValue.ListLocalPartitionsRequest.operation_params', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='path', full_name='Ydb.KeyValue.ListLocalPartitionsRequest.path', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='node_id', full_name='Ydb.KeyValue.ListLocalPartitionsRequest.node_id', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5206,
  serialized_end=5324,
)


_LISTLOCALPARTITIONSRESPONSE = _descriptor.Descriptor(
  name='ListLocalPartitionsResponse',
  full_name='Ydb.KeyValue.ListLocalPartitionsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation', full_name='Ydb.KeyValue.ListLocalPartitionsResponse.operation', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5326,
  serialized_end=5401,
)


_LISTLOCALPARTITIONSRESULT = _descriptor.Descriptor(
  name='ListLocalPartitionsResult',
  full_name='Ydb.KeyValue.ListLocalPartitionsResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='path', full_name='Ydb.KeyValue.ListLocalPartitionsResult.path', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='node_id', full_name='Ydb.KeyValue.ListLocalPartitionsResult.node_id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='partition_ids', full_name='Ydb.KeyValue.ListLocalPartitionsResult.partition_ids', index=2,
      number=3, type=4, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5403,
  serialized_end=5484,
)

_STORAGECHANNELINFO.fields_by_name['status_flag'].enum_type = _STORAGECHANNELINFO_STATUSFLAG
_STORAGECHANNELINFO_STATUSFLAG.containing_type = _STORAGECHANNELINFO
_PRIORITIES_PRIORITY.containing_type = _PRIORITIES
_STORAGECONFIG_CHANNELCONFIG.containing_type = _STORAGECONFIG
_STORAGECONFIG.fields_by_name['channel'].message_type = _STORAGECONFIG_CHANNELCONFIG
_KEYRANGE.oneofs_by_name['from_bound'].fields.append(
  _KEYRANGE.fields_by_name['from_key_inclusive'])
_KEYRANGE.fields_by_name['from_key_inclusive'].containing_oneof = _KEYRANGE.oneofs_by_name['from_bound']
_KEYRANGE.oneofs_by_name['from_bound'].fields.append(
  _KEYRANGE.fields_by_name['from_key_exclusive'])
_KEYRANGE.fields_by_name['from_key_exclusive'].containing_oneof = _KEYRANGE.oneofs_by_name['from_bound']
_KEYRANGE.oneofs_by_name['to_bound'].fields.append(
  _KEYRANGE.fields_by_name['to_key_inclusive'])
_KEYRANGE.fields_by_name['to_key_inclusive'].containing_oneof = _KEYRANGE.oneofs_by_name['to_bound']
_KEYRANGE.oneofs_by_name['to_bound'].fields.append(
  _KEYRANGE.fields_by_name['to_key_exclusive'])
_KEYRANGE.fields_by_name['to_key_exclusive'].containing_oneof = _KEYRANGE.oneofs_by_name['to_bound']
_ACQUIRELOCKREQUEST.fields_by_name['operation_params'].message_type = protos_dot_ydb__operation__pb2._OPERATIONPARAMS
_ACQUIRELOCKRESPONSE.fields_by_name['operation'].message_type = protos_dot_ydb__operation__pb2._OPERATION
_EXECUTETRANSACTIONREQUEST_COMMAND_RENAME.containing_type = _EXECUTETRANSACTIONREQUEST_COMMAND
_EXECUTETRANSACTIONREQUEST_COMMAND_CONCAT.containing_type = _EXECUTETRANSACTIONREQUEST_COMMAND
_EXECUTETRANSACTIONREQUEST_COMMAND_COPYRANGE.fields_by_name['range'].message_type = _KEYRANGE
_EXECUTETRANSACTIONREQUEST_COMMAND_COPYRANGE.containing_type = _EXECUTETRANSACTIONREQUEST_COMMAND
_EXECUTETRANSACTIONREQUEST_COMMAND_WRITE.fields_by_name['priority'].enum_type = _PRIORITIES_PRIORITY
_EXECUTETRANSACTIONREQUEST_COMMAND_WRITE.fields_by_name['tactic'].enum_type = _EXECUTETRANSACTIONREQUEST_COMMAND_WRITE_TACTIC
_EXECUTETRANSACTIONREQUEST_COMMAND_WRITE.containing_type = _EXECUTETRANSACTIONREQUEST_COMMAND
_EXECUTETRANSACTIONREQUEST_COMMAND_WRITE_TACTIC.containing_type = _EXECUTETRANSACTIONREQUEST_COMMAND_WRITE
_EXECUTETRANSACTIONREQUEST_COMMAND_DELETERANGE.fields_by_name['range'].message_type = _KEYRANGE
_EXECUTETRANSACTIONREQUEST_COMMAND_DELETERANGE.containing_type = _EXECUTETRANSACTIONREQUEST_COMMAND
_EXECUTETRANSACTIONREQUEST_COMMAND.fields_by_name['delete_range'].message_type = _EXECUTETRANSACTIONREQUEST_COMMAND_DELETERANGE
_EXECUTETRANSACTIONREQUEST_COMMAND.fields_by_name['rename'].message_type = _EXECUTETRANSACTIONREQUEST_COMMAND_RENAME
_EXECUTETRANSACTIONREQUEST_COMMAND.fields_by_name['copy_range'].message_type = _EXECUTETRANSACTIONREQUEST_COMMAND_COPYRANGE
_EXECUTETRANSACTIONREQUEST_COMMAND.fields_by_name['concat'].message_type = _EXECUTETRANSACTIONREQUEST_COMMAND_CONCAT
_EXECUTETRANSACTIONREQUEST_COMMAND.fields_by_name['write'].message_type = _EXECUTETRANSACTIONREQUEST_COMMAND_WRITE
_EXECUTETRANSACTIONREQUEST_COMMAND.containing_type = _EXECUTETRANSACTIONREQUEST
_EXECUTETRANSACTIONREQUEST_COMMAND.oneofs_by_name['action'].fields.append(
  _EXECUTETRANSACTIONREQUEST_COMMAND.fields_by_name['delete_range'])
_EXECUTETRANSACTIONREQUEST_COMMAND.fields_by_name['delete_range'].containing_oneof = _EXECUTETRANSACTIONREQUEST_COMMAND.oneofs_by_name['action']
_EXECUTETRANSACTIONREQUEST_COMMAND.oneofs_by_name['action'].fields.append(
  _EXECUTETRANSACTIONREQUEST_COMMAND.fields_by_name['rename'])
_EXECUTETRANSACTIONREQUEST_COMMAND.fields_by_name['rename'].containing_oneof = _EXECUTETRANSACTIONREQUEST_COMMAND.oneofs_by_name['action']
_EXECUTETRANSACTIONREQUEST_COMMAND.oneofs_by_name['action'].fields.append(
  _EXECUTETRANSACTIONREQUEST_COMMAND.fields_by_name['copy_range'])
_EXECUTETRANSACTIONREQUEST_COMMAND.fields_by_name['copy_range'].containing_oneof = _EXECUTETRANSACTIONREQUEST_COMMAND.oneofs_by_name['action']
_EXECUTETRANSACTIONREQUEST_COMMAND.oneofs_by_name['action'].fields.append(
  _EXECUTETRANSACTIONREQUEST_COMMAND.fields_by_name['concat'])
_EXECUTETRANSACTIONREQUEST_COMMAND.fields_by_name['concat'].containing_oneof = _EXECUTETRANSACTIONREQUEST_COMMAND.oneofs_by_name['action']
_EXECUTETRANSACTIONREQUEST_COMMAND.oneofs_by_name['action'].fields.append(
  _EXECUTETRANSACTIONREQUEST_COMMAND.fields_by_name['write'])
_EXECUTETRANSACTIONREQUEST_COMMAND.fields_by_name['write'].containing_oneof = _EXECUTETRANSACTIONREQUEST_COMMAND.oneofs_by_name['action']
_EXECUTETRANSACTIONREQUEST.fields_by_name['operation_params'].message_type = protos_dot_ydb__operation__pb2._OPERATIONPARAMS
_EXECUTETRANSACTIONREQUEST.fields_by_name['commands'].message_type = _EXECUTETRANSACTIONREQUEST_COMMAND
_EXECUTETRANSACTIONREQUEST.oneofs_by_name['_lock_generation'].fields.append(
  _EXECUTETRANSACTIONREQUEST.fields_by_name['lock_generation'])
_EXECUTETRANSACTIONREQUEST.fields_by_name['lock_generation'].containing_oneof = _EXECUTETRANSACTIONREQUEST.oneofs_by_name['_lock_generation']
_EXECUTETRANSACTIONRESPONSE.fields_by_name['operation'].message_type = protos_dot_ydb__operation__pb2._OPERATION
_EXECUTETRANSACTIONRESULT.fields_by_name['storage_channel_info'].message_type = _STORAGECHANNELINFO
_READREQUEST.fields_by_name['operation_params'].message_type = protos_dot_ydb__operation__pb2._OPERATIONPARAMS
_READREQUEST.fields_by_name['priority'].enum_type = _PRIORITIES_PRIORITY
_READREQUEST.oneofs_by_name['_lock_generation'].fields.append(
  _READREQUEST.fields_by_name['lock_generation'])
_READREQUEST.fields_by_name['lock_generation'].containing_oneof = _READREQUEST.oneofs_by_name['_lock_generation']
_READRESPONSE.fields_by_name['operation'].message_type = protos_dot_ydb__operation__pb2._OPERATION
_READRANGEREQUEST.fields_by_name['operation_params'].message_type = protos_dot_ydb__operation__pb2._OPERATIONPARAMS
_READRANGEREQUEST.fields_by_name['range'].message_type = _KEYRANGE
_READRANGEREQUEST.fields_by_name['priority'].enum_type = _PRIORITIES_PRIORITY
_READRANGEREQUEST.oneofs_by_name['_lock_generation'].fields.append(
  _READRANGEREQUEST.fields_by_name['lock_generation'])
_READRANGEREQUEST.fields_by_name['lock_generation'].containing_oneof = _READRANGEREQUEST.oneofs_by_name['_lock_generation']
_READRANGERESPONSE.fields_by_name['operation'].message_type = protos_dot_ydb__operation__pb2._OPERATION
_READRANGERESULT_KEYVALUEPAIR.containing_type = _READRANGERESULT
_READRANGERESULT.fields_by_name['pair'].message_type = _READRANGERESULT_KEYVALUEPAIR
_LISTRANGEREQUEST.fields_by_name['operation_params'].message_type = protos_dot_ydb__operation__pb2._OPERATIONPARAMS
_LISTRANGEREQUEST.fields_by_name['range'].message_type = _KEYRANGE
_LISTRANGEREQUEST.oneofs_by_name['_lock_generation'].fields.append(
  _LISTRANGEREQUEST.fields_by_name['lock_generation'])
_LISTRANGEREQUEST.fields_by_name['lock_generation'].containing_oneof = _LISTRANGEREQUEST.oneofs_by_name['_lock_generation']
_LISTRANGERESPONSE.fields_by_name['operation'].message_type = protos_dot_ydb__operation__pb2._OPERATION
_LISTRANGERESULT_KEYINFO.containing_type = _LISTRANGERESULT
_LISTRANGERESULT.fields_by_name['key'].message_type = _LISTRANGERESULT_KEYINFO
_GETSTORAGECHANNELSTATUSREQUEST.fields_by_name['operation_params'].message_type = protos_dot_ydb__operation__pb2._OPERATIONPARAMS
_GETSTORAGECHANNELSTATUSREQUEST.oneofs_by_name['_lock_generation'].fields.append(
  _GETSTORAGECHANNELSTATUSREQUEST.fields_by_name['lock_generation'])
_GETSTORAGECHANNELSTATUSREQUEST.fields_by_name['lock_generation'].containing_oneof = _GETSTORAGECHANNELSTATUSREQUEST.oneofs_by_name['_lock_generation']
_GETSTORAGECHANNELSTATUSRESPONSE.fields_by_name['operation'].message_type = protos_dot_ydb__operation__pb2._OPERATION
_GETSTORAGECHANNELSTATUSRESULT.fields_by_name['storage_channel_info'].message_type = _STORAGECHANNELINFO
_CREATEVOLUMEREQUEST.fields_by_name['operation_params'].message_type = protos_dot_ydb__operation__pb2._OPERATIONPARAMS
_CREATEVOLUMEREQUEST.fields_by_name['storage_config'].message_type = _STORAGECONFIG
_CREATEVOLUMERESPONSE.fields_by_name['operation'].message_type = protos_dot_ydb__operation__pb2._OPERATION
_DROPVOLUMEREQUEST.fields_by_name['operation_params'].message_type = protos_dot_ydb__operation__pb2._OPERATIONPARAMS
_DROPVOLUMERESPONSE.fields_by_name['operation'].message_type = protos_dot_ydb__operation__pb2._OPERATION
_ALTERVOLUMEREQUEST.fields_by_name['operation_params'].message_type = protos_dot_ydb__operation__pb2._OPERATIONPARAMS
_ALTERVOLUMEREQUEST.fields_by_name['storage_config'].message_type = _STORAGECONFIG
_ALTERVOLUMERESPONSE.fields_by_name['operation'].message_type = protos_dot_ydb__operation__pb2._OPERATION
_DESCRIBEVOLUMEREQUEST.fields_by_name['operation_params'].message_type = protos_dot_ydb__operation__pb2._OPERATIONPARAMS
_DESCRIBEVOLUMERESPONSE.fields_by_name['operation'].message_type = protos_dot_ydb__operation__pb2._OPERATION
_LISTLOCALPARTITIONSREQUEST.fields_by_name['operation_params'].message_type = protos_dot_ydb__operation__pb2._OPERATIONPARAMS
_LISTLOCALPARTITIONSRESPONSE.fields_by_name['operation'].message_type = protos_dot_ydb__operation__pb2._OPERATION
DESCRIPTOR.message_types_by_name['StorageChannelInfo'] = _STORAGECHANNELINFO
DESCRIPTOR.message_types_by_name['Priorities'] = _PRIORITIES
DESCRIPTOR.message_types_by_name['StorageConfig'] = _STORAGECONFIG
DESCRIPTOR.message_types_by_name['KeyRange'] = _KEYRANGE
DESCRIPTOR.message_types_by_name['AcquireLockRequest'] = _ACQUIRELOCKREQUEST
DESCRIPTOR.message_types_by_name['AcquireLockResponse'] = _ACQUIRELOCKRESPONSE
DESCRIPTOR.message_types_by_name['AcquireLockResult'] = _ACQUIRELOCKRESULT
DESCRIPTOR.message_types_by_name['ExecuteTransactionRequest'] = _EXECUTETRANSACTIONREQUEST
DESCRIPTOR.message_types_by_name['ExecuteTransactionResponse'] = _EXECUTETRANSACTIONRESPONSE
DESCRIPTOR.message_types_by_name['ExecuteTransactionResult'] = _EXECUTETRANSACTIONRESULT
DESCRIPTOR.message_types_by_name['ReadRequest'] = _READREQUEST
DESCRIPTOR.message_types_by_name['ReadResponse'] = _READRESPONSE
DESCRIPTOR.message_types_by_name['ReadResult'] = _READRESULT
DESCRIPTOR.message_types_by_name['ReadRangeRequest'] = _READRANGEREQUEST
DESCRIPTOR.message_types_by_name['ReadRangeResponse'] = _READRANGERESPONSE
DESCRIPTOR.message_types_by_name['ReadRangeResult'] = _READRANGERESULT
DESCRIPTOR.message_types_by_name['ListRangeRequest'] = _LISTRANGEREQUEST
DESCRIPTOR.message_types_by_name['ListRangeResponse'] = _LISTRANGERESPONSE
DESCRIPTOR.message_types_by_name['ListRangeResult'] = _LISTRANGERESULT
DESCRIPTOR.message_types_by_name['GetStorageChannelStatusRequest'] = _GETSTORAGECHANNELSTATUSREQUEST
DESCRIPTOR.message_types_by_name['GetStorageChannelStatusResponse'] = _GETSTORAGECHANNELSTATUSRESPONSE
DESCRIPTOR.message_types_by_name['GetStorageChannelStatusResult'] = _GETSTORAGECHANNELSTATUSRESULT
DESCRIPTOR.message_types_by_name['CreateVolumeRequest'] = _CREATEVOLUMEREQUEST
DESCRIPTOR.message_types_by_name['CreateVolumeResponse'] = _CREATEVOLUMERESPONSE
DESCRIPTOR.message_types_by_name['CreateVolumeResult'] = _CREATEVOLUMERESULT
DESCRIPTOR.message_types_by_name['DropVolumeRequest'] = _DROPVOLUMEREQUEST
DESCRIPTOR.message_types_by_name['DropVolumeResponse'] = _DROPVOLUMERESPONSE
DESCRIPTOR.message_types_by_name['DropVolumeResult'] = _DROPVOLUMERESULT
DESCRIPTOR.message_types_by_name['AlterVolumeRequest'] = _ALTERVOLUMEREQUEST
DESCRIPTOR.message_types_by_name['AlterVolumeResponse'] = _ALTERVOLUMERESPONSE
DESCRIPTOR.message_types_by_name['AlterVolumeResult'] = _ALTERVOLUMERESULT
DESCRIPTOR.message_types_by_name['DescribeVolumeRequest'] = _DESCRIBEVOLUMEREQUEST
DESCRIPTOR.message_types_by_name['DescribeVolumeResponse'] = _DESCRIBEVOLUMERESPONSE
DESCRIPTOR.message_types_by_name['DescribeVolumeResult'] = _DESCRIBEVOLUMERESULT
DESCRIPTOR.message_types_by_name['ListLocalPartitionsRequest'] = _LISTLOCALPARTITIONSREQUEST
DESCRIPTOR.message_types_by_name['ListLocalPartitionsResponse'] = _LISTLOCALPARTITIONSRESPONSE
DESCRIPTOR.message_types_by_name['ListLocalPartitionsResult'] = _LISTLOCALPARTITIONSRESULT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

StorageChannelInfo = _reflection.GeneratedProtocolMessageType('StorageChannelInfo', (_message.Message,), {
  'DESCRIPTOR' : _STORAGECHANNELINFO,
  '__module__' : 'draft.protos.ydb_keyvalue_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.KeyValue.StorageChannelInfo)
  })
_sym_db.RegisterMessage(StorageChannelInfo)

Priorities = _reflection.GeneratedProtocolMessageType('Priorities', (_message.Message,), {
  'DESCRIPTOR' : _PRIORITIES,
  '__module__' : 'draft.protos.ydb_keyvalue_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.KeyValue.Priorities)
  })
_sym_db.RegisterMessage(Priorities)

StorageConfig = _reflection.GeneratedProtocolMessageType('StorageConfig', (_message.Message,), {

  'ChannelConfig' : _reflection.GeneratedProtocolMessageType('ChannelConfig', (_message.Message,), {
    'DESCRIPTOR' : _STORAGECONFIG_CHANNELCONFIG,
    '__module__' : 'draft.protos.ydb_keyvalue_pb2'
    # @@protoc_insertion_point(class_scope:Ydb.KeyValue.StorageConfig.ChannelConfig)
    })
  ,
  'DESCRIPTOR' : _STORAGECONFIG,
  '__module__' : 'draft.protos.ydb_keyvalue_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.KeyValue.StorageConfig)
  })
_sym_db.RegisterMessage(StorageConfig)
_sym_db.RegisterMessage(StorageConfig.ChannelConfig)

KeyRange = _reflection.GeneratedProtocolMessageType('KeyRange', (_message.Message,), {
  'DESCRIPTOR' : _KEYRANGE,
  '__module__' : 'draft.protos.ydb_keyvalue_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.KeyValue.KeyRange)
  })
_sym_db.RegisterMessage(KeyRange)

AcquireLockRequest = _reflection.GeneratedProtocolMessageType('AcquireLockRequest', (_message.Message,), {
  'DESCRIPTOR' : _ACQUIRELOCKREQUEST,
  '__module__' : 'draft.protos.ydb_keyvalue_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.KeyValue.AcquireLockRequest)
  })
_sym_db.RegisterMessage(AcquireLockRequest)

AcquireLockResponse = _reflection.GeneratedProtocolMessageType('AcquireLockResponse', (_message.Message,), {
  'DESCRIPTOR' : _ACQUIRELOCKRESPONSE,
  '__module__' : 'draft.protos.ydb_keyvalue_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.KeyValue.AcquireLockResponse)
  })
_sym_db.RegisterMessage(AcquireLockResponse)

AcquireLockResult = _reflection.GeneratedProtocolMessageType('AcquireLockResult', (_message.Message,), {
  'DESCRIPTOR' : _ACQUIRELOCKRESULT,
  '__module__' : 'draft.protos.ydb_keyvalue_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.KeyValue.AcquireLockResult)
  })
_sym_db.RegisterMessage(AcquireLockResult)

ExecuteTransactionRequest = _reflection.GeneratedProtocolMessageType('ExecuteTransactionRequest', (_message.Message,), {

  'Command' : _reflection.GeneratedProtocolMessageType('Command', (_message.Message,), {

    'Rename' : _reflection.GeneratedProtocolMessageType('Rename', (_message.Message,), {
      'DESCRIPTOR' : _EXECUTETRANSACTIONREQUEST_COMMAND_RENAME,
      '__module__' : 'draft.protos.ydb_keyvalue_pb2'
      # @@protoc_insertion_point(class_scope:Ydb.KeyValue.ExecuteTransactionRequest.Command.Rename)
      })
    ,

    'Concat' : _reflection.GeneratedProtocolMessageType('Concat', (_message.Message,), {
      'DESCRIPTOR' : _EXECUTETRANSACTIONREQUEST_COMMAND_CONCAT,
      '__module__' : 'draft.protos.ydb_keyvalue_pb2'
      # @@protoc_insertion_point(class_scope:Ydb.KeyValue.ExecuteTransactionRequest.Command.Concat)
      })
    ,

    'CopyRange' : _reflection.GeneratedProtocolMessageType('CopyRange', (_message.Message,), {
      'DESCRIPTOR' : _EXECUTETRANSACTIONREQUEST_COMMAND_COPYRANGE,
      '__module__' : 'draft.protos.ydb_keyvalue_pb2'
      # @@protoc_insertion_point(class_scope:Ydb.KeyValue.ExecuteTransactionRequest.Command.CopyRange)
      })
    ,

    'Write' : _reflection.GeneratedProtocolMessageType('Write', (_message.Message,), {
      'DESCRIPTOR' : _EXECUTETRANSACTIONREQUEST_COMMAND_WRITE,
      '__module__' : 'draft.protos.ydb_keyvalue_pb2'
      # @@protoc_insertion_point(class_scope:Ydb.KeyValue.ExecuteTransactionRequest.Command.Write)
      })
    ,

    'DeleteRange' : _reflection.GeneratedProtocolMessageType('DeleteRange', (_message.Message,), {
      'DESCRIPTOR' : _EXECUTETRANSACTIONREQUEST_COMMAND_DELETERANGE,
      '__module__' : 'draft.protos.ydb_keyvalue_pb2'
      # @@protoc_insertion_point(class_scope:Ydb.KeyValue.ExecuteTransactionRequest.Command.DeleteRange)
      })
    ,
    'DESCRIPTOR' : _EXECUTETRANSACTIONREQUEST_COMMAND,
    '__module__' : 'draft.protos.ydb_keyvalue_pb2'
    # @@protoc_insertion_point(class_scope:Ydb.KeyValue.ExecuteTransactionRequest.Command)
    })
  ,
  'DESCRIPTOR' : _EXECUTETRANSACTIONREQUEST,
  '__module__' : 'draft.protos.ydb_keyvalue_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.KeyValue.ExecuteTransactionRequest)
  })
_sym_db.RegisterMessage(ExecuteTransactionRequest)
_sym_db.RegisterMessage(ExecuteTransactionRequest.Command)
_sym_db.RegisterMessage(ExecuteTransactionRequest.Command.Rename)
_sym_db.RegisterMessage(ExecuteTransactionRequest.Command.Concat)
_sym_db.RegisterMessage(ExecuteTransactionRequest.Command.CopyRange)
_sym_db.RegisterMessage(ExecuteTransactionRequest.Command.Write)
_sym_db.RegisterMessage(ExecuteTransactionRequest.Command.DeleteRange)

ExecuteTransactionResponse = _reflection.GeneratedProtocolMessageType('ExecuteTransactionResponse', (_message.Message,), {
  'DESCRIPTOR' : _EXECUTETRANSACTIONRESPONSE,
  '__module__' : 'draft.protos.ydb_keyvalue_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.KeyValue.ExecuteTransactionResponse)
  })
_sym_db.RegisterMessage(ExecuteTransactionResponse)

ExecuteTransactionResult = _reflection.GeneratedProtocolMessageType('ExecuteTransactionResult', (_message.Message,), {
  'DESCRIPTOR' : _EXECUTETRANSACTIONRESULT,
  '__module__' : 'draft.protos.ydb_keyvalue_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.KeyValue.ExecuteTransactionResult)
  })
_sym_db.RegisterMessage(ExecuteTransactionResult)

ReadRequest = _reflection.GeneratedProtocolMessageType('ReadRequest', (_message.Message,), {
  'DESCRIPTOR' : _READREQUEST,
  '__module__' : 'draft.protos.ydb_keyvalue_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.KeyValue.ReadRequest)
  })
_sym_db.RegisterMessage(ReadRequest)

ReadResponse = _reflection.GeneratedProtocolMessageType('ReadResponse', (_message.Message,), {
  'DESCRIPTOR' : _READRESPONSE,
  '__module__' : 'draft.protos.ydb_keyvalue_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.KeyValue.ReadResponse)
  })
_sym_db.RegisterMessage(ReadResponse)

ReadResult = _reflection.GeneratedProtocolMessageType('ReadResult', (_message.Message,), {
  'DESCRIPTOR' : _READRESULT,
  '__module__' : 'draft.protos.ydb_keyvalue_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.KeyValue.ReadResult)
  })
_sym_db.RegisterMessage(ReadResult)

ReadRangeRequest = _reflection.GeneratedProtocolMessageType('ReadRangeRequest', (_message.Message,), {
  'DESCRIPTOR' : _READRANGEREQUEST,
  '__module__' : 'draft.protos.ydb_keyvalue_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.KeyValue.ReadRangeRequest)
  })
_sym_db.RegisterMessage(ReadRangeRequest)

ReadRangeResponse = _reflection.GeneratedProtocolMessageType('ReadRangeResponse', (_message.Message,), {
  'DESCRIPTOR' : _READRANGERESPONSE,
  '__module__' : 'draft.protos.ydb_keyvalue_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.KeyValue.ReadRangeResponse)
  })
_sym_db.RegisterMessage(ReadRangeResponse)

ReadRangeResult = _reflection.GeneratedProtocolMessageType('ReadRangeResult', (_message.Message,), {

  'KeyValuePair' : _reflection.GeneratedProtocolMessageType('KeyValuePair', (_message.Message,), {
    'DESCRIPTOR' : _READRANGERESULT_KEYVALUEPAIR,
    '__module__' : 'draft.protos.ydb_keyvalue_pb2'
    # @@protoc_insertion_point(class_scope:Ydb.KeyValue.ReadRangeResult.KeyValuePair)
    })
  ,
  'DESCRIPTOR' : _READRANGERESULT,
  '__module__' : 'draft.protos.ydb_keyvalue_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.KeyValue.ReadRangeResult)
  })
_sym_db.RegisterMessage(ReadRangeResult)
_sym_db.RegisterMessage(ReadRangeResult.KeyValuePair)

ListRangeRequest = _reflection.GeneratedProtocolMessageType('ListRangeRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTRANGEREQUEST,
  '__module__' : 'draft.protos.ydb_keyvalue_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.KeyValue.ListRangeRequest)
  })
_sym_db.RegisterMessage(ListRangeRequest)

ListRangeResponse = _reflection.GeneratedProtocolMessageType('ListRangeResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTRANGERESPONSE,
  '__module__' : 'draft.protos.ydb_keyvalue_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.KeyValue.ListRangeResponse)
  })
_sym_db.RegisterMessage(ListRangeResponse)

ListRangeResult = _reflection.GeneratedProtocolMessageType('ListRangeResult', (_message.Message,), {

  'KeyInfo' : _reflection.GeneratedProtocolMessageType('KeyInfo', (_message.Message,), {
    'DESCRIPTOR' : _LISTRANGERESULT_KEYINFO,
    '__module__' : 'draft.protos.ydb_keyvalue_pb2'
    # @@protoc_insertion_point(class_scope:Ydb.KeyValue.ListRangeResult.KeyInfo)
    })
  ,
  'DESCRIPTOR' : _LISTRANGERESULT,
  '__module__' : 'draft.protos.ydb_keyvalue_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.KeyValue.ListRangeResult)
  })
_sym_db.RegisterMessage(ListRangeResult)
_sym_db.RegisterMessage(ListRangeResult.KeyInfo)

GetStorageChannelStatusRequest = _reflection.GeneratedProtocolMessageType('GetStorageChannelStatusRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETSTORAGECHANNELSTATUSREQUEST,
  '__module__' : 'draft.protos.ydb_keyvalue_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.KeyValue.GetStorageChannelStatusRequest)
  })
_sym_db.RegisterMessage(GetStorageChannelStatusRequest)

GetStorageChannelStatusResponse = _reflection.GeneratedProtocolMessageType('GetStorageChannelStatusResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETSTORAGECHANNELSTATUSRESPONSE,
  '__module__' : 'draft.protos.ydb_keyvalue_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.KeyValue.GetStorageChannelStatusResponse)
  })
_sym_db.RegisterMessage(GetStorageChannelStatusResponse)

GetStorageChannelStatusResult = _reflection.GeneratedProtocolMessageType('GetStorageChannelStatusResult', (_message.Message,), {
  'DESCRIPTOR' : _GETSTORAGECHANNELSTATUSRESULT,
  '__module__' : 'draft.protos.ydb_keyvalue_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.KeyValue.GetStorageChannelStatusResult)
  })
_sym_db.RegisterMessage(GetStorageChannelStatusResult)

CreateVolumeRequest = _reflection.GeneratedProtocolMessageType('CreateVolumeRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEVOLUMEREQUEST,
  '__module__' : 'draft.protos.ydb_keyvalue_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.KeyValue.CreateVolumeRequest)
  })
_sym_db.RegisterMessage(CreateVolumeRequest)

CreateVolumeResponse = _reflection.GeneratedProtocolMessageType('CreateVolumeResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEVOLUMERESPONSE,
  '__module__' : 'draft.protos.ydb_keyvalue_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.KeyValue.CreateVolumeResponse)
  })
_sym_db.RegisterMessage(CreateVolumeResponse)

CreateVolumeResult = _reflection.GeneratedProtocolMessageType('CreateVolumeResult', (_message.Message,), {
  'DESCRIPTOR' : _CREATEVOLUMERESULT,
  '__module__' : 'draft.protos.ydb_keyvalue_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.KeyValue.CreateVolumeResult)
  })
_sym_db.RegisterMessage(CreateVolumeResult)

DropVolumeRequest = _reflection.GeneratedProtocolMessageType('DropVolumeRequest', (_message.Message,), {
  'DESCRIPTOR' : _DROPVOLUMEREQUEST,
  '__module__' : 'draft.protos.ydb_keyvalue_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.KeyValue.DropVolumeRequest)
  })
_sym_db.RegisterMessage(DropVolumeRequest)

DropVolumeResponse = _reflection.GeneratedProtocolMessageType('DropVolumeResponse', (_message.Message,), {
  'DESCRIPTOR' : _DROPVOLUMERESPONSE,
  '__module__' : 'draft.protos.ydb_keyvalue_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.KeyValue.DropVolumeResponse)
  })
_sym_db.RegisterMessage(DropVolumeResponse)

DropVolumeResult = _reflection.GeneratedProtocolMessageType('DropVolumeResult', (_message.Message,), {
  'DESCRIPTOR' : _DROPVOLUMERESULT,
  '__module__' : 'draft.protos.ydb_keyvalue_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.KeyValue.DropVolumeResult)
  })
_sym_db.RegisterMessage(DropVolumeResult)

AlterVolumeRequest = _reflection.GeneratedProtocolMessageType('AlterVolumeRequest', (_message.Message,), {
  'DESCRIPTOR' : _ALTERVOLUMEREQUEST,
  '__module__' : 'draft.protos.ydb_keyvalue_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.KeyValue.AlterVolumeRequest)
  })
_sym_db.RegisterMessage(AlterVolumeRequest)

AlterVolumeResponse = _reflection.GeneratedProtocolMessageType('AlterVolumeResponse', (_message.Message,), {
  'DESCRIPTOR' : _ALTERVOLUMERESPONSE,
  '__module__' : 'draft.protos.ydb_keyvalue_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.KeyValue.AlterVolumeResponse)
  })
_sym_db.RegisterMessage(AlterVolumeResponse)

AlterVolumeResult = _reflection.GeneratedProtocolMessageType('AlterVolumeResult', (_message.Message,), {
  'DESCRIPTOR' : _ALTERVOLUMERESULT,
  '__module__' : 'draft.protos.ydb_keyvalue_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.KeyValue.AlterVolumeResult)
  })
_sym_db.RegisterMessage(AlterVolumeResult)

DescribeVolumeRequest = _reflection.GeneratedProtocolMessageType('DescribeVolumeRequest', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBEVOLUMEREQUEST,
  '__module__' : 'draft.protos.ydb_keyvalue_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.KeyValue.DescribeVolumeRequest)
  })
_sym_db.RegisterMessage(DescribeVolumeRequest)

DescribeVolumeResponse = _reflection.GeneratedProtocolMessageType('DescribeVolumeResponse', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBEVOLUMERESPONSE,
  '__module__' : 'draft.protos.ydb_keyvalue_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.KeyValue.DescribeVolumeResponse)
  })
_sym_db.RegisterMessage(DescribeVolumeResponse)

DescribeVolumeResult = _reflection.GeneratedProtocolMessageType('DescribeVolumeResult', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBEVOLUMERESULT,
  '__module__' : 'draft.protos.ydb_keyvalue_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.KeyValue.DescribeVolumeResult)
  })
_sym_db.RegisterMessage(DescribeVolumeResult)

ListLocalPartitionsRequest = _reflection.GeneratedProtocolMessageType('ListLocalPartitionsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTLOCALPARTITIONSREQUEST,
  '__module__' : 'draft.protos.ydb_keyvalue_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.KeyValue.ListLocalPartitionsRequest)
  })
_sym_db.RegisterMessage(ListLocalPartitionsRequest)

ListLocalPartitionsResponse = _reflection.GeneratedProtocolMessageType('ListLocalPartitionsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTLOCALPARTITIONSRESPONSE,
  '__module__' : 'draft.protos.ydb_keyvalue_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.KeyValue.ListLocalPartitionsResponse)
  })
_sym_db.RegisterMessage(ListLocalPartitionsResponse)

ListLocalPartitionsResult = _reflection.GeneratedProtocolMessageType('ListLocalPartitionsResult', (_message.Message,), {
  'DESCRIPTOR' : _LISTLOCALPARTITIONSRESULT,
  '__module__' : 'draft.protos.ydb_keyvalue_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.KeyValue.ListLocalPartitionsResult)
  })
_sym_db.RegisterMessage(ListLocalPartitionsResult)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# flake8: noqa
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: draft/ydb_dynamic_config_v1.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'draft/ydb_dynamic_config_v1.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ydb._grpc.v6.draft.protos import ydb_dynamic_config_pb2 as draft_dot_protos_dot_ydb__dynamic__config__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!draft/ydb_dynamic_config_v1.proto\x12\x14Ydb.DynamicConfig.V1\x1a%draft/protos/ydb_dynamic_config.proto2\x81\x08\n\x14\x44ynamicConfigService\x12V\n\tSetConfig\x12#.Ydb.DynamicConfig.SetConfigRequest\x1a$.Ydb.DynamicConfig.SetConfigResponse\x12\x62\n\rReplaceConfig\x12\'.Ydb.DynamicConfig.ReplaceConfigRequest\x1a(.Ydb.DynamicConfig.ReplaceConfigResponse\x12\\\n\x0bGetMetadata\x12%.Ydb.DynamicConfig.GetMetadataRequest\x1a&.Ydb.DynamicConfig.GetMetadataResponse\x12V\n\tGetConfig\x12#.Ydb.DynamicConfig.GetConfigRequest\x1a$.Ydb.DynamicConfig.GetConfigResponse\x12Y\n\nDropConfig\x12$.Ydb.DynamicConfig.DropConfigRequest\x1a%.Ydb.DynamicConfig.DropConfigResponse\x12n\n\x11\x41\x64\x64VolatileConfig\x12+.Ydb.DynamicConfig.AddVolatileConfigRequest\x1a,.Ydb.DynamicConfig.AddVolatileConfigResponse\x12w\n\x14RemoveVolatileConfig\x12..Ydb.DynamicConfig.RemoveVolatileConfigRequest\x1a/.Ydb.DynamicConfig.RemoveVolatileConfigResponse\x12\x62\n\rGetNodeLabels\x12\'.Ydb.DynamicConfig.GetNodeLabelsRequest\x1a(.Ydb.DynamicConfig.GetNodeLabelsResponse\x12\x62\n\rResolveConfig\x12\'.Ydb.DynamicConfig.ResolveConfigRequest\x1a(.Ydb.DynamicConfig.ResolveConfigResponse\x12k\n\x10ResolveAllConfig\x12*.Ydb.DynamicConfig.ResolveAllConfigRequest\x1a+.Ydb.DynamicConfig.ResolveAllConfigResponseBn\n%tech.ydb.proto.draft.dynamicconfig.v1ZBgithub.com/ydb-platform/ydb-go-genproto/draft/Ydb_DynamicConfig_V1\xf8\x01\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'draft.ydb_dynamic_config_v1_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n%tech.ydb.proto.draft.dynamicconfig.v1ZBgithub.com/ydb-platform/ydb-go-genproto/draft/Ydb_DynamicConfig_V1\370\001\001'
  _globals['_DYNAMICCONFIGSERVICE']._serialized_start=99
  _globals['_DYNAMICCONFIGSERVICE']._serialized_end=1124
# @@protoc_insertion_point(module_scope)
